from unittest import mock

from fedora_messaging.api import Message

from resultsdb_listener import consumer


example_message = Message(
    topic="org.centos.prod.ci.pipeline.test.integration.complete",
    body={
        "CI_TYPE": "custom",
        "CI_NAME": "ci-pipeline-ostree-boot-sanity",
        "topic": "org.centos.prod.ci.pipeline.test.integration.complete",
        "build_id": "79",
        "build_url": "https://ci.centos.org/job/"
        "ci-pipeline-ostree-boot-sanity/79/",
        "compose_url": "http://artifacts.ci.centos.org/artifacts/"
        "fedora-atomic/f26/ostree",
        "branch": "f26",
        "ref": "fedora/f26/x86_64/atomic-host",
        "rev": "0546fa18041a8ca223f4f441dc1868fc81ddce0f",
        "repo": "perl",
        "namespace": "rpms",
        "username": "fedora-atomic",
        "test_guidance": "<comma-separated-list-of-test-suites-to-run>",
        "message-content": "",
        "status": "SUCCESS",
    },
)
example_message.id = "random_uuid"


class TestPipelineComposeTestIntegrationComplete(object):
    @mock.patch("resultsdb_listener.consumer.senders")
    def test_parse_example_message(self, senders):
        processor = mock.MagicMock()
        senders.get_sender.return_value = processor
        cons = consumer.Consumer()
        cons(example_message)

        assert processor().send.call_count == 1
        processor().send.assert_called_with(
            {
                "msg_id": "random_uuid",
                "build_id": "79",
                "build_url": "https://ci.centos.org/job/"
                "ci-pipeline-ostree-boot-sanity/79/",
                "branch": "f26",
                "ref": "fedora/f26/x86_64/atomic-host",
                "rev": "0546fa18041a8ca223f4f441dc1868fc81ddce0f",
                "repo": "perl",
                "namespace": "rpms",
                "username": "fedora-atomic",
                "status": "SUCCESS",
                "topic": "org.centos.prod.ci.pipeline.test.integration"
                ".complete",
                "compose_url": "http://artifacts.ci.centos.org/artifacts/"
                "fedora-atomic/f26/ostree",
            }
        )
