from unittest import mock

from fedora_messaging.api import Message

from resultsdb_listener import consumer


example_message = Message(
    topic="org.centos.prod.ci.pipeline.package.complete",
    body={
        "CI_TYPE": "custom",
        "CI_NAME": "ci-pipeline-duffy-allocate-new",
        "topic": "org.centos.prod.ci.pipeline.package.complete",
        "build_id": "79",
        "build_url": "https://ci.centos.org/job/"
        "ci-pipeline-duffy-allocate-new/79/",
        "package_url": "http://artifacts.ci.centos.org/artifacts/"
        "fedora-atomic/rawhide/repo/perl_repo/perl-5.26.0-392.fc27.x86_64.rpm",
        "branch": "rawhide",
        "ref": "fedora/rawhide/x86_64/atomic-host",
        "rev": "0546fa18041a8ca223f4f441dc1868fc81ddce0f",
        "repo": "perl",
        "namespace": "rpms",
        "username": "fedora-atomic",
        "test_guidance": "''",
        "message-content": "",
        "status": "<SUCCESS/FAILURE/ABORTED>",
    },
)
example_message.id = "random_uuid"


class TestPipelinePackageComplete(object):
    @mock.patch("resultsdb_listener.consumer.senders")
    def test_parse_example_message(self, senders):
        processor = mock.MagicMock()
        senders.get_sender.return_value = processor
        cons = consumer.Consumer()
        cons(example_message)

        assert processor().send.call_count == 1
        processor().send.assert_called_with(
            {
                "msg_id": "random_uuid",
                "build_id": "79",
                "build_url": "https://ci.centos.org/job/"
                "ci-pipeline-duffy-allocate-new/79/",
                "branch": "rawhide",
                "ref": "fedora/rawhide/x86_64/atomic-host",
                "rev": "0546fa18041a8ca223f4f441dc1868fc81ddce0f",
                "repo": "perl",
                "namespace": "rpms",
                "username": "fedora-atomic",
                "status": "<SUCCESS/FAILURE/ABORTED>",
                "topic": "org.centos.prod.ci.pipeline.package.complete",
                "package_url": "http://artifacts.ci.centos.org/artifacts/"
                "fedora-atomic/rawhide/repo/perl_repo/"
                "perl-5.26.0-392.fc27.x86_64.rpm",
            }
        )
